from PropBank.ArgumentType import ArgumentType


cdef class Role(object):

    cdef str __description, __f, __n

    cpdef str getDescription(self)
    cpdef str getF(self)
    cpdef str getN(self)
    cpdef object getArgumentType(self)


from PropBank.Role cimport Role


cdef class RoleSet(object):

    cdef str __id, __name
    cdef list __roles

    cpdef str getId(self)
    cpdef str getName(self)
    cpdef int size(self)
    cpdef addRole(self, Role role)
    cpdef Role getRole(self, int index)
    cpdef Role getRoleWithArgument(self, str n)



from PropBank.ArgumentType import ArgumentType


cdef class Frameset(object):

    cdef list __framesetArguments
    cdef str __id

    cpdef bint containsArgument(self, object argumentType)
    cpdef addArgument(self, str argumentType, str definition, str function=*)
    cpdef deleteArgument(self, str argumentType, str definition)
    cpdef list getFramesetArguments(self)
    cpdef str getId(self)
    cpdef setId(self, str _id)
    cpdef save(self, str fileName)